@@ -23,7 +23,7 @@ use as_slice::AsSlice;
 use crate::{
     adc,
     pac::{self, dma1::ch::cr},
-    rcc::Rcc,
+    rcc::{Enable, Rcc, Reset},
 };
 
 #[cfg(any(feature = "io-STM32L051", feature = "io-STM32L071"))]
@@ -61,12 +61,10 @@ pub struct DMA {
 impl DMA {
     /// Create an instance of the DMA API
     pub fn new(dma: pac::DMA1, rcc: &mut Rcc) -> Self {
-        // Reset peripheral
-        rcc.rb.ahbrstr.modify(|_, w| w.dmarst().set_bit());
-        rcc.rb.ahbrstr.modify(|_, w| w.dmarst().clear_bit());
-
         // Enable peripheral clock
-        rcc.rb.ahbenr.modify(|_, w| w.dmaen().set_bit());
+        pac::DMA1::enable(rcc);
+        // Reset peripheral
+        pac::DMA1::reset(rcc);
 
         Self {
             handle: Handle { dma },
@@ -662,19 +660,9 @@ impl SupportedWordSize for u32 {
     }
 }
 
-#[derive(Clone, Copy)]
+#[derive(Clone, Copy, Default)]
 pub struct Interrupts {
     pub transfer_error: bool,
     pub half_transfer: bool,
     pub transfer_complete: bool,
 }
-
-impl Default for Interrupts {
-    fn default() -> Self {
-        Self {
-            transfer_error: false,
-            half_transfer: false,
-            transfer_complete: false,
-        }
-    }
-}
