@@ -370,6 +370,7 @@ impl Rtc {
 }
 
 /// Flags to enable/disable RTC interrupts.
+#[derive(Default)]
 pub struct Interrupts {
     pub timestamp: bool,
     pub wakeup_timer: bool,
@@ -377,17 +378,6 @@ pub struct Interrupts {
     pub alarm_b: bool,
 }
 
-impl Default for Interrupts {
-    fn default() -> Self {
-        Self {
-            timestamp: false,
-            wakeup_timer: false,
-            alarm_a: false,
-            alarm_b: false,
-        }
-    }
-}
-
 /// The RTC wakeup timer
 ///
 /// This timer can be used in two ways:
