@@ -8,7 +8,7 @@ use crate::gpio::{AltMode, PinMode};
 use crate::hal;
 use crate::hal::prelude::*;
 pub use crate::pac::{LPUART1, USART1, USART2, USART4, USART5};
-use crate::rcc::{Rcc, LSE};
+use crate::rcc::{Enable, Rcc, LSE};
 use embedded_time::rate::{Baud, Extensions};
 
 #[cfg(any(feature = "stm32l0x2", feature = "stm32l0x3"))]
@@ -294,7 +294,7 @@ pub struct Tx<USART> {
 
 macro_rules! usart {
     ($(
-        $USARTX:ident: ($usartX:ident, $apbXenr:ident, $usartXen:ident, $pclkX:ident, $SerialExt:ident),
+        $USARTX:ident: ($usartX:ident, $pclkX:ident, $SerialExt:ident),
     )+) => {
         $(
             pub trait $SerialExt<TX, RX> {
@@ -327,7 +327,7 @@ macro_rules! usart {
                     rx.setup();
 
                     // Enable clock for USART
-                    rcc.rb.$apbXenr.modify(|_, w| w.$usartXen().set_bit());
+                    <$USARTX>::enable(rcc);
 
                     // Calculate correct baudrate divisor on the fly
                     let div = (rcc.clocks.$pclkX().0 * 25) / (4 * config.baudrate.0);
@@ -496,6 +496,28 @@ macro_rules! usart {
             }
 
             impl Rx<$USARTX> {
+                /// Returns true if the line idle status is set
+                /// This reads the ISR register's IDLE bit. This bit is set by hardware
+                /// when an Idle Line is detected. And can be cleared by calling `clear_idle_interrupt`.
+                ///
+                /// This flag is set by hardware even when interrupts are disabled (IDLEIE=0 in CR1)
+                pub fn is_idle(&self) -> bool {
+                    let isr = unsafe { (*$USARTX::ptr()).isr.read() };
+                    isr.idle().bit_is_set()
+                }
+
+                /// Returns true if the rx register is not empty (and can be read)
+                pub fn is_rx_not_empty(&self) -> bool {
+                    let isr = unsafe { (*$USARTX::ptr()).isr.read() };
+                    isr.rxne().bit_is_set()
+                }
+
+                /// Clear idle line interrupt flag
+                pub fn clear_idle_interrupt(&self) {
+                    let icr = unsafe { &(*$USARTX::ptr()).icr };
+                    icr.write(|w| w.idlecf().set_bit());
+                }
+
                 /// Checks for reception errors that may have occurred.
                 ///
                 /// Note that multiple errors can be signaled at the same time. In that case,
@@ -648,6 +670,14 @@ macro_rules! usart {
                 }
             }
 
+            impl Tx<$USARTX> {
+                /// Returns true if the tx register is empty (and can accept data)
+                pub fn is_tx_empty(&self) -> bool {
+                    let isr = unsafe { (*$USARTX::ptr()).isr.read() };
+                    isr.txe().bit_is_set()
+                }
+            }
+
             #[cfg(any(feature = "stm32l0x2", feature = "stm32l0x3"))]
             impl Tx<$USARTX> {
                 pub fn write_all<Buffer, Channel>(self,
@@ -713,21 +743,21 @@ macro_rules! usart {
     feature = "io-STM32L071",
 ))]
 usart! {
-    LPUART1: (lpuart1, apb1enr, lpuart1en, apb1_clk, Serial1LpExt),
-    USART2: (usart2, apb1enr, usart2en, apb1_clk, Serial2Ext),
+    LPUART1: (lpuart1, apb1_clk, Serial1LpExt),
+    USART2: (usart2, apb1_clk, Serial2Ext),
 }
 
 // USART1 is available on category 3/5 MCUs
 #[cfg(any(feature = "io-STM32L051", feature = "io-STM32L071"))]
 usart! {
-    USART1: (usart1, apb2enr, usart1en, apb1_clk, Serial1Ext),
+    USART1: (usart1, apb1_clk, Serial1Ext),
 }
 
 // USART4 and USART5 are available on category 5 MCUs
 #[cfg(feature = "io-STM32L071")]
 usart! {
-    USART4: (usart4, apb1enr, usart4en, apb1_clk, Serial4Ext),
-    USART5: (usart5, apb1enr, usart5en, apb1_clk, Serial5Ext),
+    USART4: (usart4, apb1_clk, Serial4Ext),
+    USART5: (usart5, apb1_clk, Serial5Ext),
 }
 
 impl Serial<LPUART1> {
